International Business Machines Corporation
Logo as of 1972
IBM Watson system in 2011
Type | Public
Traded as | NYSE: IBM DJIA Component S&P 100 Component S&P 500 Component
ISIN | US4592001014
Industry | Cloud computing Cognitive computing Information technology
Founded | June 16, 1911; 106 years ago (1911-06-16) (as Computing-Tabulating-Recording Company) Endicott, New York, U.S.[1]
Founder | Charles Ranlett Flint
Headquarters | Armonk, New York, U.S.
Area served | 170 countries[2]
Key people | Ginni Rometty (Chairwoman, President and CEO)
Products | See IBM products
Revenue | US$ 79.919 billion (2016)[3]
Operating income | US$ 13.031 billion (2016)[3]
Net income | US$ 11.872 billion (2016)[3]
Total assets | US$ 117.47 billion (2016)[3]
Total equity | US$ 18.392 billion (2016)[3]
Number of employees | 380,000 (2016)[4]
Website | www.ibm.com